@@ -254,7 +254,7 @@ class ToPrimitiveTestCase(test_base.BaseTestCase):
         self.assertEqual(dict(b=1),
                          jsonutils.to_primitive(x, convert_instances=True))
 
-        self.assertEqual(x, jsonutils.to_primitive(x))
+        self.assertRaises(ValueError, jsonutils.to_primitive, x)
 
     def test_typeerror(self):
         x = bytearray  # Class, not instance
@@ -320,6 +320,11 @@ class ToPrimitiveTestCase(test_base.BaseTestCase):
         ret = jsonutils.to_primitive(thing)
         self.assertEqual({'ip_addr': '2001:db8::'}, ret)
 
+    def test_ipnet_using_netaddr(self):
+        thing = {'ip_net': netaddr.IPNetwork('1.2.3.0/24')}
+        ret = jsonutils.to_primitive(thing)
+        self.assertEqual({'ip_net': '1.2.3.0/24'}, ret)
+
     def test_message_with_param(self):
         msg = self.trans_fixture.lazy('A message with param: %s')
         msg = msg % 'test_domain'
